@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -21,9 +22,8 @@ sys.path.insert(0, os.path.abspath('../..'))
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 extensions = [
     'sphinx.ext.autodoc',
-    'oslo_config.sphinxconfiggen',
     #'sphinx.ext.intersphinx',
-    'openstackdocstheme'
+    'oslosphinx'
 ]
 
 # autodoc generation is a bit aggressive and a nuisance when doing heavy
@@ -33,21 +33,12 @@ extensions = [
 # The suffix of source filenames.
 source_suffix = '.rst'
 
-config_generator_config_file = '../../etc/networking-hyperv-config-generator.conf'
-sample_config_basename = '_static/networking-hyperv'
-
 # The master toctree document.
 master_doc = 'index'
 
 # General information about the project.
-project = 'networking-hyperv'
-copyright = '2013, OpenStack Foundation'
-
-# openstackdocstheme options
-openstackdocs_repo_name = 'openstack/networking-hyperv'
-openstackdocs_auto_name = False
-openstackdocs_bug_project = 'networking-hyperv'
-openstackdocs_bug_tag = ''
+project = u'networking-hyperv'
+copyright = u'2013, OpenStack Foundation'
 
 # If true, '()' will be appended to :func: etc. cross-reference text.
 add_function_parentheses = True
@@ -57,14 +48,15 @@ add_function_parentheses = True
 add_module_names = True
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'native'
+pygments_style = 'sphinx'
 
 # -- Options for HTML output --------------------------------------------------
 
 # The theme to use for HTML and HTML Help pages.  Major themes that come with
 # Sphinx are currently 'default' and 'sphinxdoc'.
 # html_theme_path = ["."]
-html_theme = 'openstackdocs'
+# html_theme = '_theme'
+# html_static_path = ['static']
 
 # Output file base name for HTML help builder.
 htmlhelp_basename = '%sdoc' % project
@@ -75,8 +67,8 @@ htmlhelp_basename = '%sdoc' % project
 latex_documents = [
     ('index',
      '%s.tex' % project,
-     '%s Documentation' % project,
-     'OpenStack Foundation', 'manual'),
+     u'%s Documentation' % project,
+     u'OpenStack Foundation', 'manual'),
 ]
 
 # Example configuration for intersphinx: refer to the Python standard library.
